@@ -15,12 +15,12 @@
 #'   Both absolute and scaled distances are reported as `.absdist` and
 #'   `.absdist_scaled`.
 #'
-#' @param x [tbl_interval()]
-#' @param y [tbl_interval()]
-#' @param genome [tbl_genome()]
+#' @param x [ivl_df]
+#' @param y [ivl_df]
+#' @param genome [genome_df]
 #'
 #' @return
-#' [tbl_interval()] with `.absdist` and `.absdist_scaled` columns.
+#' [ivl_df] with `.absdist` and `.absdist_scaled` columns.
 #'
 #' @template stats
 #'
@@ -39,9 +39,9 @@
 #'
 #' @export
 bed_absdist <- function(x, y, genome) {
-  if (!is.tbl_interval(x)) x <- as.tbl_interval(x)
-  if (!is.tbl_interval(y)) y <- as.tbl_interval(y)
-  if (!is.tbl_genome(genome)) genome <- as.tbl_genome(genome)
+  x <- check_interval(x)
+  y <- check_interval(y)
+  genome <- check_genome(genome)
 
   # establish grouping with shared groups (and chrom)
   groups_xy <- shared_groups(x, y)
@@ -55,20 +55,11 @@ bed_absdist <- function(x, y, genome) {
   x <- group_by(x, !!! groups_vars)
   y <- group_by(y, !!! groups_vars)
 
-  if (utils::packageVersion("dplyr") < "0.7.99.9000"){
-    x_cpp <- update_groups(x)
-    y_cpp <- update_groups(y)
-    grp_indexes <- shared_group_indexes(x_cpp, y_cpp)
-    res <- dist_impl(x_cpp, y_cpp,
-                     grp_indexes$x,
-                     grp_indexes$y,
-                     distcalc = "absdist")
-  } else {
-    grp_indexes <- shared_group_indexes(x, y)
-    res <- dist_impl(x, y,
-                     grp_indexes$x, grp_indexes$y,
-                     distcalc = "absdist")
-  }
+
+  grp_indexes <- shared_group_indexes(x, y)
+  res <- dist_impl(x, y,
+                   grp_indexes$x, grp_indexes$y,
+                   distcalc = "absdist")
 
   # convert groups_xy to character vector
   if (!is.null(groups_xy)) {
@@ -80,18 +71,18 @@ bed_absdist <- function(x, y, genome) {
   genome <- inner_join(genome, get_labels(y), by = c("chrom"))
 
   ref_points <- summarize(y, .ref_points = n())
-  genome <- inner_join(genome, ref_points, by = c("chrom", groups_xy))
+  genome <- inner_join(genome, ref_points, by = c(groups_xy))
 
   genome <- mutate(genome, .ref_gap = .ref_points / size)
   genome <- select(genome, -size, -.ref_points)
 
   # calculate scaled reference sizes
-  res <- full_join(res, genome, by = c("chrom", groups_xy))
+  res <- full_join(res, genome, by = c(groups_xy))
   res <- mutate(res, .absdist_scaled = .absdist * .ref_gap)
   res <- select(res, -.ref_gap)
 
   # report back original x intervals not found
-  x_missing <- anti_join(x, res, by = c("chrom", groups_xy))
+  x_missing <- anti_join(x, res, by = c(groups_xy))
   x_missing <- ungroup(x_missing)
   x_missing <- mutate(x_missing, .absdist = NA, .absdist_scaled = NA)
   res <- bind_rows(res, x_missing)
