@@ -29,8 +29,8 @@ NULL
 #' }
 #'
 #' @export
-db_ucsc <- function(dbname, host = 'genome-mysql.cse.ucsc.edu',
-                    user = 'genomep', password = 'password',
+db_ucsc <- function(dbname, host = "genome-mysql.cse.ucsc.edu",
+                    user = "genomep", password = "password",
                     port = 3306, ...) {
   src_mysql(dbname, host, port, user, password, ...) # nocov
 }
@@ -49,8 +49,8 @@ db_ucsc <- function(dbname, host = 'genome-mysql.cse.ucsc.edu',
 #' }
 #'
 #' @export
-db_ensembl <- function(dbname, host = 'ensembldb.ensembl.org',
-                       user = 'anonymous', password = '',
+db_ensembl <- function(dbname, host = "ensembldb.ensembl.org",
+                       user = "anonymous", password = "",
                        port = 3306, ...) {
   src_mysql(dbname, host, port, user, password, ...) # nocov
 }
