@@ -1,6 +1,6 @@
 // subtract.cpp
 //
-// Copyright (C) 2016 - 2017 Jay Hesselberth and Kent Riemondy
+// Copyright (C) 2016 - 2018 Jay Hesselberth and Kent Riemondy
 //
 // This file is part of valr.
 //
@@ -76,7 +76,9 @@ void subtract_group(ivl_vector_t vx, ivl_vector_t vy,
 }
 
 //[[Rcpp::export]]
-DataFrame subtract_impl(GroupedDataFrame gdf_x, GroupedDataFrame gdf_y) {
+DataFrame subtract_impl(ValrGroupedDataFrame gdf_x, ValrGroupedDataFrame gdf_y,
+                        IntegerVector x_grp_indexes,
+                        IntegerVector y_grp_indexes) {
 
   std::vector<std::string> chrom_out ;
   std::vector<int> starts_out ;
@@ -89,10 +91,10 @@ DataFrame subtract_impl(GroupedDataFrame gdf_x, GroupedDataFrame gdf_y) {
   std::vector<int> indices_out ;
 
   // set up interval trees for each chromosome and apply subtract_group
-  GroupApply(gdf_x, gdf_y, subtract_group, std::ref(indices_out), std::ref(starts_out), std::ref(ends_out));
+  GroupApply(gdf_x, gdf_y, x_grp_indexes, y_grp_indexes, subtract_group, std::ref(indices_out), std::ref(starts_out), std::ref(ends_out));
 
   // extract out x data, new intervals will be generated as copies of the parent interval
-  DataFrame out = DataFrameSubsetVisitors(df_x, df_x.names()).subset(indices_out, "data.frame");
+  DataFrame out = subset_dataframe(df_x, indices_out) ;
 
   // assign new starts and ends
   out["start"] = starts_out ;
