@@ -1,11 +1,11 @@
 context("utils")
 
-x <- trbl_interval(
+x <- tibble::tribble(
   ~ chrom, ~ start, ~ end,
   "chr1", 1, 100,
   "chr1", 200, 500
 )
-y <- trbl_interval(
+y <- tibble::tribble(
   ~ chrom, ~ start, ~ end,
   "chr1", 1, 100,
   "chr1", 200, 500
@@ -18,7 +18,7 @@ test_that("NULL is return when there are no shared groups, shared_groups()", {
 })
 
 test_that("only shared groups are return, shared_groups()", {
-  x <- trbl_interval(
+  x <- tibble::tribble(
     ~ chrom, ~ start, ~ end,
     "chr1", 1, 100,
     "chr1", 200, 500
@@ -30,12 +30,12 @@ test_that("only shared groups are return, shared_groups()", {
 })
 
 
-x <- trbl_interval(
+x <- tibble::tribble(
   ~ end, ~ chrom, ~ start, ~ value,
   75, "chr1", 125, 10
 )
 
-y <- trbl_interval(
+y <- tibble::tribble(
   ~ chrom, ~ start, ~ end, ~ scores,
   "chr1", 50, 100, 1.2,
   "chr1", 100, 150, 2.4
